@@ -25,8 +25,6 @@
 #ifndef __WSUTIL_CFUTILS_H__
 #define __WSUTIL_CFUTILS_H__
 
-#ifdef HAVE_OS_X_FRAMEWORKS
-
 #include "ws_symbol_export.h"
 
 #ifdef __cplusplus
@@ -42,6 +40,4 @@ WS_DLL_PUBLIC char *CFString_to_C_string(CFStringRef cfstring);
 }
 #endif /* __cplusplus */
 
-#endif /* HAVE_OS_X_FRAMEWORKS */
-
 #endif /* __WSUTIL_CFUTILS_H__ */
